### Name: PCS.boot.par
### Title: Probability of correct selection (PCS) calculator
### Aliases: PCS.boot.par PCS.exact PCS.boot.np
### Keywords: htest

### ** Examples

##### Small example for PCS.boot.par & PCS.exact
theta = c(1.0, 1.5, 1.7, 2.3, 2.5, 4.2)
T = c(1,2,3,5); G = 0:3; D = c(0.5,1,1.5); L = 1:2
PCS.boot.par(theta, T, G, D, L, B=1000, SDE=1, dist="normal", trunc=6)
PCS.exact(theta, t=2, g=1, d=NULL, m=20, tol=1e-8)

#The above assumes the largest thetas are best.
#To select the smallest thetas, reverse the order of the indices, e.g.
theta.new = max(theta) - theta + min(theta)
T = c(1,2,3,5); G = 0:3; D = c(0.5,1,1.5); L = 1:2
PCS.boot.par(theta.new, T, G, D, L, B=1000, SDE=1, dist="normal", trunc=6)
PCS.exact(theta.new, t=2, g=1, d=NULL, m=20, tol=1e-8)

##### Small example for PCS.boot.np
k=20 #number of populations
n=10 #sample size
SD=.1 #standard deviation
theta = seq(0,6,length.out=k)
X1 = rnorm(k*n,0,SD)   #Sample 1
X1 = matrix(X1,nrow=k,ncol=n,byrow=FALSE)
X2 = rnorm(k*n,theta,SD) #Sample 2, shifted
X2 = matrix(X2,nrow=k,ncol=n,byrow=FALSE)
T = c(1,2,3,5); G = 0:3; D = c(0.5,1,1.5); L = 1:2
PCS.boot.np(X1, X2, T, G, D, B=1000, trunc=6)

##### Microarray example of t-statistics with PCS.boot.par
library(multtest)
data(golub)                                                     #Load microarray data
ans = tindep(golub[,1:27], golub[,28:38], flag=1)       #Obtain t-statistics
golub.T = sort(abs(ans[,1]))                            #Massage t-statistics
T=c(1,5,10,25,50,92); G=c(1,10,25,50,150); D=c(0,1,2) #Set PCS parameters
df=18                                                           #Degrees of freedom from Satterthwaite approximation
sde=sqrt((18/(18-2))/19)                                        #Estimate SDE by method of moments SD, divided by mean sample size
PCS.boot.par(golub.T, T, G, D, L=NULL, B=100, SDE=sde, dist="t", df=18) #Small bootstrap sample size for speed

##### Microarray example of Golub's correlation statistics (see reference) with PCS.boot.par
library(multtest)
data(golub)                                                     #Load microarray data
Pgc <- function(x,y) {                                          #Function to calculate Golub's correlation statistics
  xbar1 = apply(x,1,mean)
  xbar2 = apply(y,1,mean)
  sd1   = apply(x,1,sd)
  sd2   = apply(y,1,sd)
  Pgc = abs((xbar1-xbar2))/(sd1+sd2)
  return(Pgc)
} #end function
Pgc.gol = Pgc(golub[,1:27],golub[,28:38])                       #Calculate correlation statistics
T=c(1,5,10,25,50,92); G=c(1,10,25,50,150); D=c(0,1,2)   #Set PCS parameters
sde=0.20                                                                #Obtained by simulation on Golub data
PCS.boot.par(Pgc.gol, T, G, D, L=NULL, B=100, SDE=0.2, dist="t", df=18) #Small bootstrap sample size for speed

##### Microarray example using non-parametric bootstrap
library(multtest)
data(golub)                                                     #Load microarray data
T=c(1,5,10); G=c(1,3,5); D=c(0,1,2)                     #Set PCS parameters
PCS.boot.np(golub[,1:27], golub[,28:38], T, G, D, B=10, trunc=6) #Small bootstrap sample size for speed



